==> org.eclipse.xtext.xtext.generator.source_2.11.0.v20170130-0808.jar: org/eclipse/xtext/xtext/generator/model/TextFileAccess.java <==
/**
 * Copyright (c) 2015 itemis AG (http://www.itemis.eu) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.eclipse.xtext.xtext.generator.model;

import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtend2.lib.StringConcatenationClient;
import org.eclipse.xtext.generator.IFileSystemAccess2;
import org.eclipse.xtext.xbase.lib.ObjectExtensions;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;
import org.eclipse.xtext.xbase.lib.Pure;

@SuppressWarnings("all")
public class TextFileAccess {
  @Accessors
  private String path;
  
  protected CharSequence internalContents;
  
  public void setContent(final StringConcatenationClient content) {
    StringConcatenation _stringConcatenation = new StringConcatenation();
    final Procedure1<StringConcatenation> _function = (StringConcatenation it) -> {
      it.append(content);
    };
    StringConcatenation _doubleArrow = ObjectExtensions.<StringConcatenation>operator_doubleArrow(_stringConcatenation, _function);
    this.internalContents = _doubleArrow;
  }
  
  public CharSequence getContent() {
    return this.internalContents.toString();
  }
  
  public void writeTo(final IFileSystemAccess2 fileSystemAccess) {
    if ((fileSystemAccess != null)) {
      fileSystemAccess.generateFile(this.path, this.getContent());
    }
  }
  
  @Pure
  public String getPath() {
    return this.path;
  }
  
  public void setPath(final String path) {
    this.path = path;
  }
}

==> org.eclipse.xtext.xtext.generator.source_2.13.0.v20171020-0708.jar: org/eclipse/xtext/xtext/generator/model/TextFileAccess.java <==
/**
 * Copyright (c) 2015 itemis AG (http://www.itemis.eu) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.eclipse.xtext.xtext.generator.model;

import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtend2.lib.StringConcatenationClient;
import org.eclipse.xtext.generator.IFileSystemAccess2;
import org.eclipse.xtext.xbase.lib.ObjectExtensions;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;
import org.eclipse.xtext.xbase.lib.Pure;

/**
 * A utility class for generating plain text files.
 */
@SuppressWarnings("all")
public class TextFileAccess {
  @Accessors
  private String path;
  
  protected CharSequence internalContents;
  
  public void setContent(final StringConcatenationClient content) {
    StringConcatenation _stringConcatenation = new StringConcatenation();
    final Procedure1<StringConcatenation> _function = (StringConcatenation it) -> {
      it.append(content);
    };
    StringConcatenation _doubleArrow = ObjectExtensions.<StringConcatenation>operator_doubleArrow(_stringConcatenation, _function);
    this.internalContents = _doubleArrow;
  }
  
  public CharSequence getContent() {
    return this.internalContents.toString();
  }
  
  public String getContentString() {
    return this.getContent().toString();
  }
  
  public void writeTo(final IFileSystemAccess2 fileSystemAccess) {
    if ((fileSystemAccess != null)) {
      fileSystemAccess.generateFile(this.path, this.getContent());
    }
  }
  
  @Pure
  public String getPath() {
    return this.path;
  }
  
  public void setPath(final String path) {
    this.path = path;
  }
}
